%define dotnet_version     3.1
%define dotnet_release     rh-dotnet31
%define  instDir           /usr/lib/dotnet/NuPkgs
%define  artifactory       https://artifactory.oci.oraclecorp.com/api/nuget/oci-dex-release-nuget-local


Name:       oci-dotnet-sdk		
Version:	27.0.0
Release: 1%{?dist}
Group:		Oracle Cloud Infrastructure
Summary:    Oracle Cloud Infrastructure SDK for .NET
License:	UPL 1.0 and Apache 2.0 
URL:		https://github.com/oracle/oci-dotnet-sdk
Source0:	%{name}-%{version}.tar.bz2
Source1:    oci-dotnet-sdk.csproj
Source2:    nuget.config
Source3:    name-mapping.txt
Buildarch:  noarch
AutoReq:    no

%if "%{?dist}" == ".el7"
BuildRequires:	%{?dotnet_release}-dotnet >= %{dotnet_version} 
Requires:	    %{?dotnet_release}-dotnet >= %{dotnet_version}
%else
BuildRequires:	dotnet >= %{dotnet_version} 
Requires:	    dotnet >= %{dotnet_version}
%endif

%description
The oci-dotnet-sdk provides Oracle Cloud Infrastructure SDK for .NET 
that you can use to manage your Oracle Cloud Infrastructure resources.

Please add or copy  nuget.config to ~/.config/NuGet/nuget.config
 
%prep
%setup -q -n %{name}-%{version}

sed -i '/.*tests/,+1d' oci-dotnet-sdk.sln
sed -i '/Examples/,+1d' oci-dotnet-sdk.sln

packFile=oci-dotnet-sdk.csproj
cp %{SOURCE1} .

cspFiles=`ls */*.csproj |grep -v .*tests |grep -v Examples`
for csp in $cspFiles; do 
       pkgName=`basename $csp .csproj`
       echo "    <PackageReference Include=\"${pkgName}\" Version=\"%{version}\" />" >>$packFile
done
echo -n "  </ItemGroup>
</Project>
" >>$packFile


%build
unset https_proxy
unset http_proxy

%if "%{?dist}" == ".el7"
which dotnet ||  source /opt/rh/%{dotnet_release}/enable
%endif
dotnet nuget locals all -c
dotnet restore -s %{artifactory}
mv oci-dotnet-sdk.sln oci-dotnet-sdk.sln.old
dotnet restore -s %{artifactory}


%check 
#make unit-test

%install
mkdir -p %{buildroot}%{instDir}
NuPkgs=`find ~/.nuget/ -name "oci.dotnet*.nupkg"`
for nupkg in $NuPkgs; do
    lastname=`basename $nupkg .%version.nupkg|cut -d. -f3`
    cp $nupkg %{buildroot}%{instDir}/OCI.DotNetSDK.${lastname^}.%version.nupkg
done

cp %{SOURCE3} .
NuPkgs=`find ~/.nuget/ -name "*.nupkg"|grep -v "oci.dotnetsdk"`
for nupkg in $NuPkgs; do
    bnameV=`basename $nupkg .nupkg`
    bname=`echo ${bnameV} |sed 's/\.[0-9].*//i'`
    bVersion=`echo ${bnameV/${bname}./}`
    tName=`grep "$bname" name-mapping.txt |awk '{print $2}'`
    [ "$tName" != "" ] || exit 1
    cp $nupkg %{buildroot}%{instDir}/${tName}.${bVersion}.nupkg
done

cp %{SOURCE2} .

%files
%{instDir}/*
%doc *.md *.txt nuget.config Examples/ 

%pre
instDir=/usr/lib/dotnet/NuPkgs
[ -d $instDir ] ||  mkdir -p $instDir 

%changelog
* Tue Oct 05 2021 EL Errata <el-errata_ww@oracle.com> 27.0.0-1
- Update to 27.0.0

* Tue Sep 28 2021 EL Errata <el-errata_ww@oracle.com> 26.0.0-1
- Update to 26.0.0

* Tue Sep 14 2021 EL Errata <el-errata_ww@oracle.com> 25.1.0-1
- Update to 25.1.0

* Tue Sep 07 2021 EL Errata <el-errata_ww@oracle.com> 25.0.0-1
- Update to 25.0.0

* Tue Aug 31 2021 EL Errata <el-errata_ww@oracle.com> 24.2.0-1
- Update to 24.2.0

* Tue Aug 24 2021 EL Errata <el-errata_ww@oracle.com> 24.1.0-1
- Update to 24.1.0

* Tue Aug 17 2021 EL Errata <el-errata_ww@oracle.com> 24.0.0-1
- Update to 24.0.0

* Tue Aug 03 2021 EL Errata <el-errata_ww@oracle.com> 23.2.0-1
- Update to 23.2.0

* Tue Jul 27 2021 EL Errata <el-errata_ww@oracle.com> 23.1.0-1
- Update to 23.1.0

* Tue Jul 20 2021 EL Errata <el-errata_ww@oracle.com> 23.0.0-1
- Update to 23.0.0

* Tue Jul 13 2021 EL Errata <el-errata_ww@oracle.com> 22.0.0-1
- Update to 22.0.0

* Tue Jul 06 2021 EL Errata <el-errata_ww@oracle.com> 21.1.0-1
- Update to 21.1.0

* Tue Jun 29 2021 EL Errata <el-errata_ww@oracle.com> 21.0.0-1
- Update to 21.0.0

* Tue Jun 22 2021 EL Errata <el-errata_ww@oracle.com> 20.1.0-1
- Update to 20.1.0

* Tue Jun 15 2021 EL Errata <el-errata_ww@oracle.com> 20.0.0-1
- Update to 20.0.0

* Tue Jun 08 2021 EL Errata <el-errata_ww@oracle.com> 19.2.0-1
- Update to 19.2.0

* Tue Jun 01 2021 EL Errata <el-errata_ww@oracle.com> 19.1.0-1
- Update to 19.1.0

* Tue May 25 2021 EL Errata <el-errata_ww@oracle.com> 19.0.0-1
- Update to 19.0.0

* Tue May 18 2021 EL Errata <el-errata_ww@oracle.com> 18.5.0-1
- Update to 18.5.0

* Tue May 11 2021 EL Errata <el-errata_ww@oracle.com> 18.4.0-1
- Update to 18.4.0

* Tue May 04 2021 EL Errata <el-errata_ww@oracle.com> 18.3.0-1
- Update to 18.3.0

* Tue Apr 27 2021 EL Errata <el-errata_ww@oracle.com> 18.2.0-1
- Update to 18.2.0

* Tue Apr 20 2021 EL Errata <el-errata_ww@oracle.com> 18.1.0-1
- Update to 18.1.0

* Tue Apr 13 2021 EL Errata <el-errata_ww@oracle.com> 18.0.0-1
- Update to 18.0.0

* Tue Apr 06 2021 EL Errata <el-errata_ww@oracle.com> 17.1.0-1
- Update to 17.1.0

* Tue Mar 30 2021 EL Errata <el-errata_ww@oracle.com> 17.0.0-1
- Update to 17.0.0

* Tue Mar 23 2021 EL Errata <el-errata_ww@oracle.com> 16.0.0-1
- Update to 16.0.0

* Tue Mar 16 2021 EL Errata <el-errata_ww@oracle.com> 15.2.0-1
- Update to 15.2.0

* Tue Mar 09 2021 EL Errata <el-errata_ww@oracle.com> 15.1.0-1
- Update to 15.1.0

* Tue Mar 02 2021 EL Errata <el-errata_ww@oracle.com> 15.0.0-1
- Update to 15.0.0

* Tue Feb 23 2021 EL Errata <el-errata_ww@oracle.com> 14.2.0-1
- Update to 14.2.0

* Tue Feb 16 2021 EL Errata <el-errata_ww@oracle.com> 14.1.0-1
- Update to 14.1.0

* Tue Feb 09 2021 EL Errata <el-errata_ww@oracle.com> 14.0.0-1
- Update to 14.0.0

* Tue Feb 02 2021 EL Errata <el-errata_ww@oracle.com> 13.0.0-1
- Update to 13.0.0

* Tue Jan 26 2021 EL Errata <el-errata_ww@oracle.com> 12.0.0-1
- Update to 12.0.0

* Tue Jan 19 2021 EL Errata <el-errata_ww@oracle.com> 11.0.0-1
- Update to 11.0.0

* Tue Jan 12 2021 EL Errata <el-errata_ww@oracle.com> 10.0.0-1
- Update to 10.0.0

* Tue Dec 15 2020 EL Errata <el-errata_ww@oracle.com> 9.0.0-1
- Update to 9.0.0

* Tue Dec 08 2020 EL Errata <el-errata_ww@oracle.com> 8.1.0-1
- Update to 8.1.0

* Tue Dec 01 2020 EL Errata <el-errata_ww@oracle.com> 8.0.0-1
- Update to 8.0.0

* Tue Nov 17 2020 EL Errata <el-errata_ww@oracle.com> 7.0.0-1
- Update to 7.0.0

* Tue Nov 10 2020 EL Errata <el-errata_ww@oracle.com> 6.2.0-1
- Update to 6.2.0

* Mon Nov 09 2020 EL Errata <el-errata_ww@oracle.com> 6.1.0-1.0.1
- Remove Examples from build
- Add <clear /> to nuget.config

* Tue Nov 03 2020 EL Errata <el-errata_ww@oracle.com> 6.1.0-1
- Update to 6.1.0

* Tue Oct 27 2020 EL Errata <el-errata_ww@oracle.com> 6.0.0-1
- Update to 6.0.0

* Tue Oct 20 2020 EL Errata <el-errata_ww@oracle.com> 5.1.0-1
- Update to 5.1.0

* Wed Oct 14 2020 Qing Lin <qing.lin@oracle.com> - 5.0.1-1.el7
- update to 5.0.1

* Wed Oct 14 2020 Qing Lin <qing.lin@oracle.com> -5.0.1-1 
- Build for first RPM release.

* Mon Oct 12 2020 Qing Lin <qing.lin@oracle.com> -4.7.0-1 
- Update to 4.7.0.

* Mon Sep 21 2020 Qing Lin <qing.lin@oracle.com> -4.3.0-1.0.1 
- Pack the prebuild OCI.DotNetSDK nupkgs from OCI artifactory instead.

* Fri Sep 11 2020 Qing Lin <qing.lin@oracle.com> -4.3.0-1 
- Update to 4.3.0
- Add dependency system.identitymodel.tokens.jwt.6.7.1.nupkg
- And its dependencies: system.security.cryptography.cng, microsoft.identitymodel.logging, tokens, jsonwetokens

* Fri Aug 28 2020 Qing Lin <qing.lin@oracle.com> -4.1.0 
- Initial build

